pub struct Jar(/* private fields */);Available on (crate features
cookies or cookies-abstract) and crate feature cookies only.Expand description
A good default CookieStore implementation.
This is the implementation used when simply calling cookie_store(true).
This type is exposed to allow creating one and filling it with some
existing cookies more easily, before creating a Client.
Implementations